#
# spec file for package flacon
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2014-2018 Alexander Evseev <aevseev@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           flacon
Version:        12.0.0
Release:        1.1
Summary:        Audio File Encoder
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            https://flacon.github.io/
Source:         https://github.com/flacon/flacon/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  zlib-devel
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  pkgconfig(taglib)
BuildRequires:  pkgconfig(uchardet)
Recommends:     faac
Recommends:     flac
Recommends:     lame
Recommends:     mac
Recommends:     opus-tools
Recommends:     sox
Recommends:     ttaenc
Recommends:     vorbis-tools
Recommends:     wavpack

%description
Flacon extracts individual tracks from one big audio file containing the entire
album of music and saves them as separate audio files. To do this, it uses
information from the appropriate CUE file. Besides, Flacon makes it possible
to conveniently revise or specify tags both for all tracks at once or for each
tag separately.

%lang_package

%prep
%autosetup

%build
%cmake
%cmake_build

%install
%cmake_install
%find_lang %{name} --with-qt

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/flacon.png
%{_datadir}/icons/hicolor/scalable/apps/flacon.svg
%{_datadir}/metainfo/com.github.Flacon.metainfo.xml
%{_mandir}/man1/%{name}.1%{?ext_man}

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations

%changelog
* Mon Feb 17 2025 Andrea Manzini <andrea.manzini@suse.com>
- Update to 12.0.0:
  * Added columns to the table to display the tags “Date”, “Genre” and
    “Song writer”.
  * Added the ability to specify a proxy server to get disk information from
    internet.
  * Added a dialog for viewing the log. Now if you have a problem you can
    send me logs just by copying them from this dialog.
  * Significantly revised display and editing of tags. The tags are now more
    clearly divided into album related and track related.
  * Increased speed of disk validation for errors in output files.
  * The limits for the Disk Number and Number of Disks fields have been
    increased to 999.
  * Bug fix. The program crashed after the end of conversion if an old
    version of Qt was used. In particular, crashes of AppImage version are fixed
  * Bug fix. Sometimes the program selected wrong directory for output files.
  * Compatibility with macOS and FreeBSD has been improved.
  * Many minor fixes and improvements.
  * Translations updated.
* Mon May  6 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 11.4.0:
  * Improved pre-conversion checks. Now the program checks that tracks from different discs are not mixed.
  * Compatibility of the output CUE with some players has been improved.
  * Added ability to build a program using Qt6.
  * Minor appearance improvements and minor bug fixes.
  * Translations updated.
- Build still uses Qt5, upcoming Qt6
* Thu Oct  5 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 11.3.0:
  * Fix. Program incorrect work with pre-emphased disks
  * Fix. Sometimes the program did not save the output directory
  * Improved audio file search for multiaudio discs.
  * For multi-audio discs, a check has been added that the same audio files are not specified for tracks.
  * Improved delete source dialogue
  * Minor fixes and improvements
  * Translations updated
* Tue Jun 20 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 11.2.0:
  * The "convert" button on the toolbar can trigger two actions:
    Convert - Converts all tracks (previous behavior)
    Convert selected - Converts only selected tracks
* Tue May 30 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 11.1.0:
  * Fix: In some situations, the program did not check whether the sox program was installed.
* Sat May 20 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 11.0.0:
  * If you try to close the program while the conversion is in progress, the program will ask for confirmation
  * Added a menu item to delete the source files for successfully converted disks
  * Small fixes to the algorithm for creating per track CUE files
  * Improved diagnostics of erroneous situations:
  * Error if tracks overwrite files (taking into account the template)
  * Error if there are tracks with the same track number and creating files in the same directory. The pattern doesn't matter
  * Warning if any disks use the same CUE file
  * Warning if any disks use the same audio file
  * Fix: The program show an error when the source files are located on slow network drives
  * Fix: The program show an error on WV files larger than 2 gigabytes
  * Minor fixes
  * Translations updated
* Tue Jan 24 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 10.0.0:
  * Now the program does not use external utilities to calculate ReplayGain, instead the built-in method is used. This accelerated the conversion process and reduced the number of dependencies.
  * For package maintainers: Note that metaflac, mp3gain, vorbisgain and wvgain are no longer needed.
  * Improved error handling. Before starting the conversion, you can view all errors and warnings in one window.
  * Fixed bug: When changing the “Artist” field, the “Album Artist” field mistakenly becomes “Multiple Values”
  * Translations updated
* Mon Dec 26 2022 Andrea Manzini <andrea.manzini@suse.com>
- fix spec for building on openSUSE_Backports_SLE-15-SP5
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 9.5.1:
  * Fixed bug: In the tag editing fields, the text cursor jumped to the end
    of the line after entering a letter.
  * Before starting the conversion, the program checks that the disks will
    not overwrite each other's output files.
  * Translations updated
  * Fixed bug: In the tag editing fields, the text cursor jumped to the end
    of the line after entering a letter.
  * Before starting the conversion, the program checks that the disks will
    not overwrite each other's output files.
* Thu Nov 10 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 9.4.0
  * fix to work with CUE files containing multiple audio file tags
  * Translations updated
  * The program gives a clear error message if the necessary utilities (sox, encoders, etc.) are missing
  * Improved algorithm of cover auto selection. Square pictures have a priority over other.
  * Fixed a bug with text color on tooltips in Linux.
  * You can now get tags from MusicBrainz and Discogs.
  * Support for CUE files with gaps appended to the end of the previous track
  * Added support for ALAC output files, Sony Wave64 input files.
  * Added the ability to embed the cover in the output ALAC, AAC, MP3, Opus and WavPack files.
  * Fix: If the CUE file contains two discs, then the program incorrectly calculated the duration of the tracks.
  * The program automatically calculates the number of threads to encode. You can change this in the preferences dialog.
  * The program can split huge FLAC files (more than 4GB)
  * You can not only copy the cover image to a file, but also embed it in the output FLAC files.
  * Improved the preferences dialog. The settings are divided into separate tabs.
  * Added support for pre-emphasis CD images.
* Tue Apr 27 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.0.1
  * Added informative error messages when the program can't load
    an audio file:
    + The audio file does not exist.
    + The audio file may be corrupted or an unsupported audio
    format.
    + Decoder program is not installed.
    + Decoder program is installed in the settings but binary
    file does not exist.
  * Improved warning messages:
    + Do not show a warning if the output format does not
    support the quality of the input HD audio, but you have
    set the correct bits per sample and sample rate in the
    preferences.
  * Redesigned the logic of loading CUE files containing
    multiple files, for example, 2 sides of an LP. Now they are
    displayed as a single list, have a single track numbering,
    and allow you to change album tags in a single operation.
  * Fixed: Flacon refuses to compute ReplayGain for no good
    reason.
  * Improved search for covers arts.
  * Added better icons for dark themes.
  * Added a few codepages for some East Asian languages.
  * Translations updated.
* Sat Jun 27 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.1.0
  * Save TOTALDISCS and DISCNUMBER tags to the output CUE file.
  * Now the program removes temporary files more carefully.
  * Imporove main menu items.
  * Because freedb.org died, the program uses gnudb.org instead.
    Added a graphical interface for selecting other CDDB
    servers.
  * Translations updated.
* Sun May 31 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.0.0
  * Added support of profiles, you can have different encoding
    options for different cases, such as maximum quality for your
    computer, and CD quality for your phone.
  * Improved usability of the preferences dialog.
  * Now the program generates file names that are safe for
    Windows file systems.
  * Support for sampling rates greater than 192000 Hz.
  * When used in console mode, the program prints information
    about the status of tracks conversion.
  * Many small improvements and bug fixes.
  * Translations updated.
* Fri Mar 13 2020 Luigi Baldoni <aloisio@gmx.com>
- Recommend faac
- Remove obsolete -lang Recommends
* Sun Feb 23 2020 Kyrill Detinov <lazy.kent@opensuse.org>
- Fix runtime dependencies: doesn't require shntool.
- Add Recommends: mp3gain, ttaenc.
* Wed Nov 27 2019 Luigi Baldoni <aloisio@gmx.com>
- Initial package (v5.5.1)
